(function ($, Drupal) {

  'use strict';

  /**
   * Behavior for the flyout menu toggle.
   */
  Drupal.behaviors.flyoutMenuToggle = {
    attach: function (context, settings) {
      var body = once('flyout-menu-toggle', 'body').shift();
      var toggle = document.querySelector('button.flyout-menu-toggle');

      if (body) {
        toggle.addEventListener('click', function (event) {
          event.preventDefault();
          toggle.classList.toggle('is-open');
          document.body.classList.toggle('flyout-menu-open');
        });
      }
    }
  };

  /**
   * Behavior for the flyout menu.
   */
  Drupal.behaviors.flyoutMenu = {
    attach: function (context, settings) {
      var body = once('flyout-menu', 'body').shift();
      var subMenuToggles = document.querySelectorAll('.sub-menu-toggle');

      if (body) {
        resize(settings.flyoutMenu.breakpoint);

        subMenuToggles.forEach(function (subMenuToggle) {
          subMenuToggle.addEventListener('click', function (event) {
            event.preventDefault();
            subMenuToggle.parentNode.classList.toggle('sub-menu-open');
          });
        });

        if (settings.flyoutMenu.breakpoint != 'none') {
          window.addEventListener('resize', function(event) {
            resize(settings.flyoutMenu.breakpoint);
          });
        }
      }
    }
  };

  function resize(breakpoint) {
    var mq = window.matchMedia(breakpoint);

    if (mq.matches) {
      document.body.classList.remove('flyout-menu-mobile');
    }
    else {
      document.body.classList.add('flyout-menu-mobile');
    }
  }

})(jQuery, Drupal);
